@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0x591ca843
+# __coconut_hash__ = 0x231ac271
 
-# Compiled with Coconut version 1.4.3-post_dev57 [Ernest Scribbler]
+# Compiled with Coconut version 1.5.0-post_dev12 [Fish License]
 
 """
 The backend and algorithm registries.
@@ -18,7 +18,7 @@ if _coconut_cached_module is not None and _coconut_os_path.dirname(_coconut_cach
     del _coconut_sys.modules[str("__coconut__")]
 _coconut_sys.path.insert(0, _coconut_file_path)
 from __coconut__ import *
-from __coconut__ import _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match
+from __coconut__ import _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
 if _coconut_sys.version_info >= (3,):
     _coconut_sys.path.pop(0)
 
@@ -54,12 +54,20 @@ class Registry(_coconut.object):
                 valid_names = ", ".join((repr(name) for name in self))
                 raise ValueError("unknown {_coconut_format_0}: {_coconut_format_1} (valid {_coconut_format_2}s: {_coconut_format_3})".format(_coconut_format_0=(self.obj_name), _coconut_format_1=(name), _coconut_format_2=(self.obj_name), _coconut_format_3=(valid_names)))
 
-    def register(self, name, value):
+    def register(self, name, value, replace=False):
         """Register value under the given name."""
+        if not replace and name in self.registered:
+            raise ValueError("cannot register already existing name {_coconut_format_0!r}".format(_coconut_format_0=(name)))
+        if name in self.aliases:
+            raise ValueError("cannot register name with existing alias {_coconut_format_0!r}".format(_coconut_format_0=(name)))
         self.registered[name] = value
 
-    def register_alias(self, name, alias):
+    def register_alias(self, name, alias, replace=False):
         """Register an alias for the given name."""
+        if not replace and alias in self.aliases:
+            raise ValueError("cannot register already existing alias {_coconut_format_0!r}".format(_coconut_format_0=(alias)))
+        if alias in self.registered:
+            raise ValueError("cannot register overlapping alias {_coconut_format_0!r}".format(_coconut_format_0=(alias)))
         self.aliases[alias] = name
 
     def run_gen(self, name):
@@ -126,36 +134,4 @@ class Registry(_coconut.object):
 backend_registry = Registry("backend")
 
 
-@_coconut_mark_as_match
-def init_backend(*_coconut_match_to_args, **_coconut_match_to_kwargs):
-    """Create a backend object of the given name with the given data."""
-    _coconut_match_check = False
-    _coconut_FunctionMatchError = _coconut_get_function_match_error()
-    if (_coconut.sum((_coconut.len(_coconut_match_to_args) > 0, "name" in _coconut_match_to_kwargs)) == 1) and (_coconut.sum((_coconut.len(_coconut_match_to_args) > 1, "examples" in _coconut_match_to_kwargs)) == 1) and (_coconut.sum((_coconut.len(_coconut_match_to_args) > 2, "params" in _coconut_match_to_kwargs)) == 1):
-        _coconut_match_temp_0 = _coconut_match_to_args[0] if _coconut.len(_coconut_match_to_args) > 0 else _coconut_match_to_kwargs.pop("name")
-        _coconut_match_temp_1 = _coconut_match_to_args[1] if _coconut.len(_coconut_match_to_args) > 1 else _coconut_match_to_kwargs.pop("examples")
-        _coconut_match_temp_2 = _coconut_match_to_args[2] if _coconut.len(_coconut_match_to_args) > 2 else _coconut_match_to_kwargs.pop("params")
-        args = _coconut_match_to_args[3:]
-        _coconut_match_temp_3 = _coconut_match_to_kwargs.pop("attempt_to_update_backend") if "attempt_to_update_backend" in _coconut_match_to_kwargs else None
-        name = _coconut_match_temp_0
-        examples = _coconut_match_temp_1
-        params = _coconut_match_temp_2
-        attempt_to_update_backend = _coconut_match_temp_3
-        options = _coconut_match_to_kwargs
-        _coconut_match_check = True
-    if not _coconut_match_check:
-        raise _coconut_FunctionMatchError('match def init_backend(name, examples, params, *args, attempt_to_update_backend=None, **options):', _coconut_match_to_args)
-
-    backend_cls = backend_registry[name]
-    if attempt_to_update_backend is not None and isinstance(attempt_to_update_backend, backend_cls):
-        updated_backend = attempt_to_update_backend.attempt_update(examples, params, *args, **options)
-        if updated_backend is True:
-            return attempt_to_update_backend
-        elif isinstance(updated_backend, backend_cls):
-            return updated_backend
-        else:
-            assert updated_backend is False, "invalid backend.attempt_update return value {_coconut_format_0} from {_coconut_format_1}".format(_coconut_format_0=(updated_backend), _coconut_format_1=(backend_cls))
-    return backend_cls(examples, params, *args, **options)
-
-
 alg_registry = Registry("algorithm")
