@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0xfdb677c2
+# __coconut_hash__ = 0x398edda4
 
-# Compiled with Coconut version 1.4.3-post_dev57 [Ernest Scribbler]
+# Compiled with Coconut version 1.5.0-post_dev12 [Fish License]
 
 # Coconut Header: -------------------------------------------------------------
 
@@ -14,7 +14,7 @@ if _coconut_cached_module is not None and _coconut_os_path.dirname(_coconut_cach
     del _coconut_sys.modules[str("__coconut__")]
 _coconut_sys.path.insert(0, _coconut_file_path)
 from __coconut__ import *
-from __coconut__ import _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match
+from __coconut__ import _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
 if _coconut_sys.version_info >= (3,):
     _coconut_sys.path.pop(0)
 
@@ -71,7 +71,7 @@ def call_test(args, ignore_errs=(), prepend_py=True):
     (print)((stdout + stderr).strip())
     clean_stderr = []
     for line in stderr.splitlines():
-        if not any((ignore in line for ignore in _coconut.itertools.chain.from_iterable((_coconut_func() for _coconut_func in (lambda: always_ignore_errs, lambda: ignore_errs))))):
+        if not any((ignore in line for ignore in _coconut.itertools.chain.from_iterable(_coconut_reiterable(_coconut_func() for _coconut_func in (lambda: always_ignore_errs, lambda: ignore_errs))))):
             clean_stderr.append(line)
     clean_stderr = "\n".join(clean_stderr)
     assert not retcode and not clean_stderr, clean_stderr
@@ -99,6 +99,9 @@ random_data = os.path.join(example_dir, "random_example.bbopt.pickle")
 skopt_file = os.path.join(example_dir, "skopt_example.py")
 skopt_data = os.path.join(example_dir, "skopt_example.bbopt.pickle")
 
+pysot_file = os.path.join(example_dir, "pysot_example.py")
+pysot_data = os.path.join(example_dir, "pysot_example.bbopt.pickle")
+
 hyperopt_file = os.path.join(example_dir, "hyperopt_example.py")
 hyperopt_data = os.path.join(example_dir, "hyperopt_example.bbopt.pickle")
 
@@ -132,7 +135,7 @@ class TestExamples(unittest.TestCase):
             from bbopt.examples import random_example
             random_example.bb.get_data(print_data=True)
             assert random_example.x == want
-            assert 1 <= random_example.x <= 10
+            assert 1 < random_example.x <= 10
             assert random_example.bb.num_examples == NUM_TRIALS
 
     def test_skopt(self):
@@ -143,10 +146,25 @@ class TestExamples(unittest.TestCase):
             assert os.path.exists(skopt_data)
 
             from bbopt.examples import skopt_example
+            skopt_example.bb.get_data(print_data=True)
             assert skopt_example.y == want
-            assert -9 <= skopt_example.y <= 21
+            assert -9 <= skopt_example.y < 21
             assert skopt_example.bb.num_examples == NUM_TRIALS
 
+    if sys.version_info >= (3,):
+        def test_pysot(self):
+            print("\ntest pysot:")
+            with using(pysot_data):
+                results = call_test(["bbopt", pysot_file, "-n", "2", "-j", "2"])
+                want = min(get_nums(results, numtype=float))
+                assert os.path.exists(pysot_data)
+
+                from bbopt.examples import pysot_example
+                pysot_example.bb.get_data(print_data=True)
+                assert pysot_example.best_y == want
+                assert -9 <= pysot_example.best_y < 21
+                assert pysot_example.bb.num_examples == 20
+
     def test_hyperopt(self):
         print("\ntest hyperopt:")
         with using(hyperopt_data):
@@ -155,6 +173,7 @@ class TestExamples(unittest.TestCase):
             assert os.path.exists(hyperopt_data)
 
             from bbopt.examples import hyperopt_example
+            hyperopt_example.bb.get_data(print_data=True)
             assert hyperopt_example.y == want
             assert hyperopt_example.bb.num_examples == NUM_TRIALS
 
@@ -166,8 +185,9 @@ class TestExamples(unittest.TestCase):
             assert os.path.exists(conditional_hyperopt_data)
 
             from bbopt.examples import conditional_hyperopt_example
+            conditional_hyperopt_example.bb.get_data(print_data=True)
             assert conditional_hyperopt_example.x == want
-            assert 0 <= conditional_hyperopt_example.x <= 20
+            assert 0 < conditional_hyperopt_example.x <= 20
             assert conditional_hyperopt_example.bb.num_examples == NUM_TRIALS
 
     def test_conditional_skopt(self):
@@ -178,8 +198,9 @@ class TestExamples(unittest.TestCase):
             assert os.path.exists(conditional_skopt_data)
 
             from bbopt.examples import conditional_skopt_example
+            conditional_skopt_example.bb.get_data(print_data=True)
             assert conditional_skopt_example.x == want
-            assert 0 <= conditional_skopt_example.x <= 20
+            assert 0 < conditional_skopt_example.x <= 20
             assert conditional_skopt_example.bb.num_examples == NUM_TRIALS
 
     def test_numpy(self):
@@ -208,7 +229,8 @@ class TestExamples(unittest.TestCase):
 
             reload(mixture_example)
             assert mixture_example.loss == want
-            assert 0 <= mixture_example.loss <= 85
+            assert 0 <= mixture_example.loss < 85
+            assert (len)((set)((map)(_coconut_base_compose(_coconut.operator.itemgetter(("memo")), (_coconut.operator.itemgetter(("alg")), 0)), mixture_example.bb.get_data()["examples"]))) > 1
             assert mixture_example.bb.num_examples == NUM_TRIALS
 
     def test_json(self):
